/* Title: Drive Window
	Name: Eric Walsh
	Description: This file contains creation options for the Drive Button.
*/

#ifndef _DRIVE_H_
#define _DRIVE_H_ 1

#define DR_ERR -1

/* The Following are the Drive Bank Creation Style(s) */

#define DRS_MULTIPLESEL     0x00000001L
#define DRS_CONSTANTSELECT  0x00000002L

/* Explanation of above Creation Style(s)
	DRS_MULITPLESEL      - Allows for the selection of more then one drive at a
								  time.
   DRS_CONSTANTSELECT   - Makes sure once one button is selected one always stays
                          selected (depressed).
*/

/* The following are the drive bank messages. */

#define DR_GETACTIVEDRIVE     (WM_USER +0x0001)
#define DR_GETNUMDRIVES			(WM_USER +0x0002)
#define DR_GETDRIVESTATE      (WM_USER +0x0003)
#define DR_SETDRIVESTATE      (WM_USER +0x0004)
#define DR_GETNUMACTIVEDRIVES (WM_USER +0x0005)

/*
--------------------------------------------------------------------------------

DR_GETACTIVEDRIVE  -Currently (last) selected drive button
	wParam        -->0
	lParam        -->0L

	RETURN VALUE: Returns the drive letter represented by the button.

--------------------------------------------------------------------------------

DR_GETNUMDRIVES  -Gets the number of drives in the drive bank control
	wParam        -->0
	lParam        -->0L

	RETURN VALUE: Returns the number of buttons in the drive bank.  DR_ERR
					  is returned if there is an error

--------------------------------------------------------------------------------

DR_GETDRIVESTATE  -Gets the state of the specified drive.
	wParam        -->drive to query. 0 is A, 1 is B etc.
	lParam        -->0L

	RETURN VALUE: Returns the state of the specified drive.
					  FALSE button is up. TRUE button is down. DR_ERR is returned
					  if the drive bank is not set with DRS_MULTIPLESEL

--------------------------------------------------------------------------------

DR_SETDRIVESTATE  -Sets the state of the specified drive.
	wParam        -->State to set drive button, FALSE is up, TRUE is down.
	lParam        -->drive to query. 0 is A, 1 is B etc.

	RETURN VALUE: Returns the state of the specified drive.
					  FALSE button is up. TRUE button is down. DR_ERR is returned
					  if the drive bank is not set with DRS_MULTIPLESEL

--------------------------------------------------------------------------------

DR_GETNUMACTIVEDRIVES  -Gets the number of depressed drives
	wParam        -->0
	lParam        -->0L

	RETURN VALUE: Returns the number of depressed drives
					  FALSE button is up. TRUE button is down. DR_ERR is returned
					  if the drive bank is not set with DRS_MULTIPLESEL

--------------------------------------------------------------------------------

*/

/* The following are the notification messages are sent from the drive bank. */
/* All of these messages are sent under the WM_COMMAND message.              */

#define DRN_DRIVECHANGE      0x0001
#define DRN_DRIVERESELECTED  0x0002

/* Below are the explanations for the above Drive Notification messages

--------------------------------------------------------------------------------

DRN_DRIVECHANGE     -Sent when a drive has been selected or deselected
	wParam       --> Specifies the identifier of the editable listbox
	lParam       --> Specifies handle of editable listbox in the low word,
						  and specifies DRN_DRIVECHANGE in the high word.

--------------------------------------------------------------------------------

DRN_DRIVERESELECTED -Sent when a currently selected button is reselected.
	wParam       --> Specifies the identifier of the editable listbox
	lParam       --> Specifies handle of editable listbox in the low word,
						  and specifies DRN_DRIVERESELECTED in the high word.

--------------------------------------------------------------------------------

*/

#endif
