/* Title: Progress Bar Control
	 Name: Eric Walsh
	 Description: This file contains the user called messages to the progress bar
					  control.
*/

#ifndef _PROGBAR_H_
#define _PROGBAR_H_  1

/***** The following are the styles that can be sent to the progress bar ******/

#define PBS_SHOWTEXTPERCENT 0x000001
#define PBS_VERTICALBAR     0x000002
#define PBS_3DBAR           0x000004
#define PBS_BITMAPBAR       0x000008

/*
PBS_SHOWTEXTPERCENT -will place a textual numberic value in the center of the
							progress bar to show the completion percentage.
PBS_VERTICALBAR     -will move the bar in a vertical position from top to bottom
PBS_3DBAR           -Draws a chiseled 3D bar, selected is raised, unselected is
							sunken.
PBS_BITMAPBAR       -Draws the progress bar with a supplied bitmap.							
*/

#define PB_ERR -1

/******* The following are the user sendable message to the progress bar ******/

#define PB_SETFILLBRUSH		  (WM_USER +0x0001)
#define PB_SETBARTEXTCOLOR   (WM_USER +0x0002)
#define PB_SETBARRANGE       (WM_USER +0x0003)
#define PB_GETLOWBARRANGE    (WM_USER +0x0004)
#define PB_GETHIGHBARRANGE   (WM_USER +0x0005)
#define PB_SETDRAWRANGE      (WM_USER +0x0006)
#define PB_GETRIGHTDRAWRANGE (WM_USER +0x0007)
#define PB_SETPROGBARBITMAP  (WM_USER +0x0008)

/*
--------------------------------------------------------------------------------

PB_SETFILLBRUSH  -Sets the progress fill bar to the specified Brush.  The start
						default brush is BLUE (0, 0, 255), unless I change my mind.
	wParam        -->Handle to a Brush
	lParam        -->States whether to redraw the control

	RETURN VALUE: TRUE

--------------------------------------------------------------------------------

PB_SETBARTEXTCOLOR -Sets the color to draw the progress percentage with.  This
						  is to be used with the PBS_SHOWTEXTPERCENT creation style.

	wParam        -->0
	lParam        -->RGB color to draw text.

	RETURN VALUE: TRUE if set, FALSE if not.

	--------------------------------------------------------------------------------

PB_GETLOWBARRANGE  -Returns the low end bar range.
	wParam        -->0
	lParam        -->0L

	RETURN VALUE: Low end bar range.

--------------------------------------------------------------------------------

PB_GETHIGHBARRANGE  -Returns the high end bar range.
	wParam        -->0
	lParam        -->0L

	RETURN VALUE: High end bar range.

--------------------------------------------------------------------------------

PB_SETBARRANGE   -Sets the range of values that the bar draw between.  The
						default range if 0 to 100 but the most most range can be from
						0 to 2^16 -1 and the right range can be from 0 to 2^32 -1.
						The right range most always be greater than the left.
	wParam        -->Left most range
	lParam        -->Right most range

	RETURN VALUE: TRUE if a valid range, PB_ERR is returned if there is an error.

--------------------------------------------------------------------------------

PB_SETDRAWRANGE  -Sets the drawing range for the status bar.  The message also
						invalidates the region and drops the new area.  Only the
						newly added area is a drawn, with old remaining the same.
	wParam        -->Begin Range to Draw from.  If -1 is specified for this
						  parameter then the draw range is set to the previous
						  farthest reight range.
	lParam        -->End Range to Draw To.

	Note: The ranges for both are the ranges set with PB_SETBARRANGE (0 to 100)
	      by default.  The right range must be greater than the left.

	RETURN VALUE: TRUE if a valid range and succesful, PB_ERR if not.

--------------------------------------------------------------------------------

PB_GETRIGHTRANGE  -Gets the rights right drawing range for the progress bar.
	wParam        -->0
	lParam        -->0L

	RETURN VALUE: The right draw point which is within the range setu with
					  PB_SETBARRANGE or 0 to 100 by default.  PB_ERR is returned if
					  a draw range has not been established.  The left draw point is
					  the same as the left range point. 

--------------------------------------------------------------------------------

PB_SETPROGBARBITMAP -Sets the bitmap to use with a bitmapped bar.  Progress bar
						 must have been created using the PBS_BITMAPBAR creation
						 style.

	wParam        -->Bitmap Handle
	lParam        -->0L

	RETURN VALUE: TRUE if able to set bitmap, FALSE if not
--------------------------------------------------------------------------------
*/
#endif
